@@ -143,8 +143,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x0840, 0x085b},
 {0x085e, 0x085e},
 {0x0860, 0x086a},
-{0x0870, 0x088e},
-{0x0890, 0x0891},
+{0x0870, 0x0891},
 {0x0897, 0x0983},
 {0x0985, 0x098c},
 {0x098f, 0x0990},
@@ -228,7 +227,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x0c4a, 0x0c4d},
 {0x0c55, 0x0c56},
 {0x0c58, 0x0c5a},
-{0x0c5d, 0x0c5d},
+{0x0c5c, 0x0c5d},
 {0x0c60, 0x0c63},
 {0x0c66, 0x0c6f},
 {0x0c77, 0x0c8c},
@@ -240,7 +239,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x0cc6, 0x0cc8},
 {0x0cca, 0x0ccd},
 {0x0cd5, 0x0cd6},
-{0x0cdd, 0x0cde},
+{0x0cdc, 0x0cde},
 {0x0ce0, 0x0ce3},
 {0x0ce6, 0x0cef},
 {0x0cf1, 0x0cf3},
@@ -337,7 +336,8 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1a7f, 0x1a89},
 {0x1a90, 0x1a99},
 {0x1aa0, 0x1aad},
-{0x1ab0, 0x1ace},
+{0x1ab0, 0x1add},
+{0x1ae0, 0x1aeb},
 {0x1b00, 0x1b4c},
 {0x1b4e, 0x1bf3},
 {0x1bfc, 0x1c37},
@@ -397,7 +397,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x20a9, 0x20a9},
 {0x20aa, 0x20ab},
 {0x20ac, 0x20ac},
-{0x20ad, 0x20c0},
+{0x20ad, 0x20c1},
 {0x20d0, 0x20f0},
 {0x2100, 0x2102},
 {0x2103, 0x2103},
@@ -640,8 +640,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x2b55, 0x2b55},
 {0x2b56, 0x2b59},
 {0x2b5a, 0x2b73},
-{0x2b76, 0x2b95},
-{0x2b97, 0x2cf3},
+{0x2b76, 0x2cf3},
 {0x2cf9, 0x2d25},
 {0x2d27, 0x2d27},
 {0x2d2d, 0x2d2d},
@@ -676,11 +675,8 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0xa490, 0xa4c6},
 {0xa4d0, 0xa62b},
 {0xa640, 0xa6f7},
-{0xa700, 0xa7cd},
-{0xa7d0, 0xa7d1},
-{0xa7d3, 0xa7d3},
-{0xa7d5, 0xa7dc},
-{0xa7f2, 0xa82c},
+{0xa700, 0xa7dc},
+{0xa7f1, 0xa82c},
 {0xa830, 0xa839},
 {0xa840, 0xa877},
 {0xa880, 0xa8c5},
@@ -717,10 +713,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0xfb3e, 0xfb3e},
 {0xfb40, 0xfb41},
 {0xfb43, 0xfb44},
-{0xfb46, 0xfbc2},
-{0xfbd3, 0xfd8f},
-{0xfd92, 0xfdc7},
-{0xfdcf, 0xfdcf},
+{0xfb46, 0xfdcf},
 {0xfdf0, 0xfdff},
 {0xfe00, 0xfe0f},
 {0xfe10, 0xfe19},
@@ -796,7 +789,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x108f4, 0x108f5},
 {0x108fb, 0x1091b},
 {0x1091f, 0x10939},
-{0x1093f, 0x1093f},
+{0x1093f, 0x10959},
 {0x10980, 0x109b7},
 {0x109bc, 0x109cf},
 {0x109d2, 0x10a03},
@@ -828,8 +821,9 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x10e80, 0x10ea9},
 {0x10eab, 0x10ead},
 {0x10eb0, 0x10eb1},
-{0x10ec2, 0x10ec4},
-{0x10efc, 0x10f27},
+{0x10ec2, 0x10ec7},
+{0x10ed0, 0x10ed8},
+{0x10efa, 0x10f27},
 {0x10f30, 0x10f59},
 {0x10f70, 0x10f89},
 {0x10fb0, 0x10fcb},
@@ -912,6 +906,7 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x11a50, 0x11aa2},
 {0x11ab0, 0x11af8},
 {0x11b00, 0x11b09},
+{0x11b60, 0x11b67},
 {0x11bc0, 0x11be1},
 {0x11bf0, 0x11bf9},
 {0x11c00, 0x11c08},
@@ -934,6 +929,8 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x11d90, 0x11d91},
 {0x11d93, 0x11d98},
 {0x11da0, 0x11da9},
+{0x11db0, 0x11ddb},
+{0x11de0, 0x11de9},
 {0x11ee0, 0x11ef8},
 {0x11f00, 0x11f10},
 {0x11f12, 0x11f3a},
@@ -963,14 +960,16 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x16b7d, 0x16b8f},
 {0x16d40, 0x16d79},
 {0x16e40, 0x16e9a},
+{0x16ea0, 0x16eb8},
+{0x16ebb, 0x16ed3},
 {0x16f00, 0x16f4a},
 {0x16f4f, 0x16f87},
 {0x16f8f, 0x16f9f},
 {0x16fe0, 0x16fe4},
-{0x16ff0, 0x16ff1},
-{0x17000, 0x187f7},
-{0x18800, 0x18cd5},
-{0x18cff, 0x18d08},
+{0x16ff0, 0x16ff6},
+{0x17000, 0x18cd5},
+{0x18cff, 0x18d1e},
+{0x18d80, 0x18df2},
 {0x1aff0, 0x1aff3},
 {0x1aff5, 0x1affb},
 {0x1affd, 0x1affe},
@@ -985,8 +984,10 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1bc80, 0x1bc88},
 {0x1bc90, 0x1bc99},
 {0x1bc9c, 0x1bca3},
-{0x1cc00, 0x1ccf9},
+{0x1cc00, 0x1ccfc},
 {0x1cd00, 0x1ceb3},
+{0x1ceba, 0x1ced0},
+{0x1cee0, 0x1cef0},
 {0x1cf00, 0x1cf2d},
 {0x1cf30, 0x1cf46},
 {0x1cf50, 0x1cfc3},
@@ -1041,6 +1042,9 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1e4d0, 0x1e4f9},
 {0x1e5d0, 0x1e5fa},
 {0x1e5ff, 0x1e5ff},
+{0x1e6c0, 0x1e6de},
+{0x1e6e0, 0x1e6f5},
+{0x1e6fe, 0x1e6ff},
 {0x1e7e0, 0x1e7e6},
 {0x1e7e8, 0x1e7eb},
 {0x1e7ed, 0x1e7ee},
@@ -1155,14 +1159,13 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1f6cd, 0x1f6cf},
 {0x1f6d0, 0x1f6d2},
 {0x1f6d3, 0x1f6d4},
-{0x1f6d5, 0x1f6d7},
+{0x1f6d5, 0x1f6d8},
 {0x1f6dc, 0x1f6df},
 {0x1f6e0, 0x1f6ea},
 {0x1f6eb, 0x1f6ec},
 {0x1f6f0, 0x1f6f3},
 {0x1f6f4, 0x1f6fc},
-{0x1f700, 0x1f776},
-{0x1f77b, 0x1f7d9},
+{0x1f700, 0x1f7d9},
 {0x1f7e0, 0x1f7eb},
 {0x1f7f0, 0x1f7f0},
 {0x1f800, 0x1f80b},
@@ -1172,22 +1175,24 @@ static const char32_t unicode_eastasia_tab[][2]={
 {0x1f890, 0x1f8ad},
 {0x1f8b0, 0x1f8bb},
 {0x1f8c0, 0x1f8c1},
+{0x1f8d0, 0x1f8d8},
 {0x1f900, 0x1f90b},
 {0x1f90c, 0x1f93a},
 {0x1f93b, 0x1f93b},
 {0x1f93c, 0x1f945},
 {0x1f946, 0x1f946},
 {0x1f947, 0x1f9ff},
-{0x1fa00, 0x1fa53},
+{0x1fa00, 0x1fa57},
 {0x1fa60, 0x1fa6d},
 {0x1fa70, 0x1fa7c},
-{0x1fa80, 0x1fa89},
-{0x1fa8f, 0x1fac6},
-{0x1face, 0x1fadc},
-{0x1fadf, 0x1fae9},
-{0x1faf0, 0x1faf8},
+{0x1fa80, 0x1fa8a},
+{0x1fa8e, 0x1fac6},
+{0x1fac8, 0x1fac8},
+{0x1facd, 0x1fadc},
+{0x1fadf, 0x1faea},
+{0x1faef, 0x1faf8},
 {0x1fb00, 0x1fb92},
-{0x1fb94, 0x1fbf9},
+{0x1fb94, 0x1fbfa},
 {0x20000, 0x2fffd},
 {0x30000, 0x3fffd},
 {0xe0001, 0xe0001},
@@ -1484,7 +1489,6 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
@@ -1562,6 +1566,7 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
@@ -1855,7 +1860,6 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
@@ -1883,9 +1887,6 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
@@ -1918,9 +1919,6 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_A,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
@@ -2165,6 +2163,12 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
@@ -2195,6 +2199,8 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
@@ -2286,6 +2292,9 @@ UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
@@ -2361,9 +2370,9 @@ UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
+UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
-UNICODE_EASTASIA_W,
-UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
@@ -2385,6 +2394,7 @@ UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_W,
+UNICODE_EASTASIA_W,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_N,
 UNICODE_EASTASIA_W,
