@@ -226,7 +226,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1a6d & 0xFF, 0x1a72 & 0xFF},
 	{0x1a73 & 0xFF, 0x1a7c & 0xFF},
 	{0x1a7f & 0xFF, 0x1a7f & 0xFF},
-	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
+	{0x1ab0 & 0xFF, 0x1add & 0xFF},
+	{0x1ae0 & 0xFF, 0x1aeb & 0xFF},
 	{0x1b00 & 0xFF, 0x1b03 & 0xFF},
 	{0x1b04 & 0xFF, 0x1b04 & 0xFF},
 	{0x1b34 & 0xFF, 0x1b3d & 0xFF},
@@ -1183,7 +1184,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x10d24 & 0xFF, 0x10d27 & 0xFF},
 	{0x10d69 & 0xFF, 0x10d6d & 0xFF},
 	{0x10eab & 0xFF, 0x10eac & 0xFF},
-	{0x10efc & 0xFF, 0x10eff & 0xFF},
+	{0x10efa & 0xFF, 0x10eff & 0xFF},
 	{0x10f46 & 0xFF, 0x10f50 & 0xFF},
 	{0x10f82 & 0xFF, 0x10f85 & 0xFF},
 	{0x11000 & 0xFF, 0x11000 & 0xFF},
@@ -1317,7 +1318,6 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11a01 & 0xFF, 0x11a0a & 0xFF},
 	{0x11a33 & 0xFF, 0x11a38 & 0xFF},
 	{0x11a39 & 0xFF, 0x11a39 & 0xFF},
-	{0x11a3a & 0xFF, 0x11a3a & 0xFF},
 	{0x11a3b & 0xFF, 0x11a3e & 0xFF},
 	{0x11a47 & 0xFF, 0x11a47 & 0xFF},
 	{0x11a51 & 0xFF, 0x11a56 & 0xFF},
@@ -1327,6 +1327,12 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11a8a & 0xFF, 0x11a96 & 0xFF},
 	{0x11a97 & 0xFF, 0x11a97 & 0xFF},
 	{0x11a98 & 0xFF, 0x11a99 & 0xFF},
+	{0x11b60 & 0xFF, 0x11b60 & 0xFF},
+	{0x11b61 & 0xFF, 0x11b61 & 0xFF},
+	{0x11b62 & 0xFF, 0x11b64 & 0xFF},
+	{0x11b65 & 0xFF, 0x11b65 & 0xFF},
+	{0x11b66 & 0xFF, 0x11b66 & 0xFF},
+	{0x11b67 & 0xFF, 0x11b67 & 0xFF},
 	{0x11c2f & 0xFF, 0x11c2f & 0xFF},
 	{0x11c30 & 0xFF, 0x11c36 & 0xFF},
 	{0x11c38 & 0xFF, 0x11c3d & 0xFF},
@@ -1404,6 +1410,10 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1e2ec & 0xFF, 0x1e2ef & 0xFF},
 	{0x1e4ec & 0xFF, 0x1e4ef & 0xFF},
 	{0x1e5ee & 0xFF, 0x1e5ef & 0xFF},
+	{0x1e6e3 & 0xFF, 0x1e6e3 & 0xFF},
+	{0x1e6e6 & 0xFF, 0x1e6e6 & 0xFF},
+	{0x1e6ee & 0xFF, 0x1e6ef & 0xFF},
+	{0x1e6f5 & 0xFF, 0x1e6f5 & 0xFF},
 	{0x1e8d0 & 0xFF, 0x1e8d6 & 0xFF},
 	{0x1e944 & 0xFF, 0x1e94a & 0xFF},
 	{0x1f1e6 & 0xFF, 0x1f1ff & 0xFF},
@@ -1658,6 +1668,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
@@ -2747,7 +2758,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
-	UNICODE_GRAPHEMEBREAK_Prepend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -2757,6 +2767,12 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_SpacingMark,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
@@ -2836,6 +2852,10 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
+	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Regional_Indicator,
 	UNICODE_GRAPHEMEBREAK_Extend,
 	UNICODE_GRAPHEMEBREAK_Control,
@@ -2957,6 +2977,7 @@ static const size_t unicode_starting_indextab[]={
 	280,
 	281,
 	282,
+	283,
 	284,
 	285,
 	286,
@@ -2977,6 +2998,7 @@ static const size_t unicode_starting_indextab[]={
 	482,
 	484,
 	485,
+	486,
 	488,
 	489,
 	497,
@@ -3021,122 +3043,124 @@ static const char32_t unicode_starting_pagetab[]={
 	201,
 	206,
 	214,
-	228,
-	247,
-	259,
+	229,
+	248,
 	260,
-	267,
+	261,
 	268,
-	270,
-	272,
-	276,
-	288,
-	303,
-	322,
-	329,
-	349,
-	368,
-	387,
-	406,
-	425,
-	444,
-	463,
-	483,
-	502,
-	521,
-	540,
-	559,
-	578,
-	597,
-	617,
-	636,
-	655,
-	674,
-	693,
-	712,
-	731,
-	751,
-	770,
-	789,
-	808,
-	827,
-	846,
-	865,
-	885,
-	904,
-	923,
-	942,
-	961,
-	980,
-	999,
-	1019,
-	1038,
-	1057,
-	1076,
-	1095,
-	1114,
-	1133,
-	1153,
-	1166,
+	269,
+	271,
+	273,
+	277,
+	289,
+	304,
+	323,
+	330,
+	350,
+	369,
+	388,
+	407,
+	426,
+	445,
+	464,
+	484,
+	503,
+	522,
+	541,
+	560,
+	579,
+	598,
+	618,
+	637,
+	656,
+	675,
+	694,
+	713,
+	732,
+	752,
+	771,
+	790,
+	809,
+	828,
+	847,
+	866,
+	886,
+	905,
+	924,
+	943,
+	962,
+	981,
+	1000,
+	1020,
+	1039,
+	1058,
+	1077,
+	1096,
+	1115,
+	1134,
+	1154,
 	1167,
-	1170,
-	1172,
+	1168,
+	1171,
 	1173,
 	1174,
 	1175,
-	1181,
-	1183,
-	1185,
-	1187,
-	1202,
-	1218,
-	1227,
-	1253,
-	1271,
-	1279,
-	1290,
-	1296,
-	1300,
-	1315,
+	1176,
+	1182,
+	1184,
+	1186,
+	1188,
+	1203,
+	1219,
+	1228,
+	1254,
+	1272,
+	1280,
+	1291,
+	1297,
+	1301,
+	1316,
 	1328,
-	1340,
-	1352,
-	1354,
-	1362,
-	1365,
+	1334,
+	1346,
+	1358,
+	1360,
 	1368,
-	1369,
-	1370,
-	1372,
-	1377,
-	1379,
-	1381,
+	1371,
+	1374,
+	1375,
+	1376,
+	1378,
+	1383,
+	1385,
 	1387,
-	1388,
+	1393,
 	1394,
 	1400,
-	1401,
-	1403,
-	1404,
-	1405,
 	1406,
 	1407,
-	1408,
 	1409,
-	1412,
-	1414,
+	1410,
+	1411,
 	1415,
 	1416,
 	1417,
 	1418,
 	1419,
-	1420,
-	1421,
 	1422,
-	1423,
 	1424,
 	1425,
 	1426,
-	1427
+	1427,
+	1428,
+	1429,
+	1430,
+	1431,
+	1432,
+	1433,
+	1434,
+	1435,
+	1436,
+	1437
 };
 
