@@ -76,8 +76,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0840 & 0xFF, 0x085b & 0xFF},
 	{0x085e & 0xFF, 0x085e & 0xFF},
 	{0x0860 & 0xFF, 0x086a & 0xFF},
-	{0x0870 & 0xFF, 0x088e & 0xFF},
-	{0x0890 & 0xFF, 0x0891 & 0xFF},
+	{0x0870 & 0xFF, 0x0891 & 0xFF},
 	{0x0897 & 0xFF, 0x08e1 & 0xFF},
 	{0x08e2 & 0xFF, 0x08e2 & 0xFF},
 	{0x08e3 & 0xFF, 0x08ff & 0xFF},
@@ -169,7 +168,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0c4a & 0xFF, 0x0c4d & 0xFF},
 	{0x0c55 & 0xFF, 0x0c56 & 0xFF},
 	{0x0c58 & 0xFF, 0x0c5a & 0xFF},
-	{0x0c5d & 0xFF, 0x0c5d & 0xFF},
+	{0x0c5c & 0xFF, 0x0c5d & 0xFF},
 	{0x0c60 & 0xFF, 0x0c63 & 0xFF},
 	{0x0c66 & 0xFF, 0x0c6f & 0xFF},
 	{0x0c77 & 0xFF, 0x0c7f & 0xFF},
@@ -182,7 +181,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0cc6 & 0xFF, 0x0cc8 & 0xFF},
 	{0x0cca & 0xFF, 0x0ccd & 0xFF},
 	{0x0cd5 & 0xFF, 0x0cd6 & 0xFF},
-	{0x0cdd & 0xFF, 0x0cde & 0xFF},
+	{0x0cdc & 0xFF, 0x0cde & 0xFF},
 	{0x0ce0 & 0xFF, 0x0ce3 & 0xFF},
 	{0x0ce6 & 0xFF, 0x0cef & 0xFF},
 	{0x0cf1 & 0xFF, 0x0cf3 & 0xFF},
@@ -301,7 +300,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1a7f & 0xFF, 0x1a89 & 0xFF},
 	{0x1a90 & 0xFF, 0x1a99 & 0xFF},
 	{0x1aa0 & 0xFF, 0x1aad & 0xFF},
-	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
+	{0x1ab0 & 0xFF, 0x1add & 0xFF},
+	{0x1ae0 & 0xFF, 0x1aeb & 0xFF},
 	{0x1b00 & 0xFF, 0x1b4c & 0xFF},
 	{0x1b4e & 0xFF, 0x1b7f & 0xFF},
 	{0x1b80 & 0xFF, 0x1bbf & 0xFF},
@@ -365,7 +365,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x207f & 0xFF, 0x207f & 0xFF},
 	{0x2080 & 0xFF, 0x208e & 0xFF},
 	{0x2090 & 0xFF, 0x209c & 0xFF},
-	{0x20a0 & 0xFF, 0x20c0 & 0xFF},
+	{0x20a0 & 0xFF, 0x20c1 & 0xFF},
 	{0x20d0 & 0xFF, 0x20f0 & 0xFF},
 	{0x2100 & 0xFF, 0x2125 & 0xFF},
 	{0x2126 & 0xFF, 0x2126 & 0xFF},
@@ -391,8 +391,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x2900 & 0xFF, 0x29ff & 0xFF},
 	{0x2a00 & 0xFF, 0x2aff & 0xFF},
 	{0x2b00 & 0xFF, 0x2b73 & 0xFF},
-	{0x2b76 & 0xFF, 0x2b95 & 0xFF},
-	{0x2b97 & 0xFF, 0x2bff & 0xFF},
+	{0x2b76 & 0xFF, 0x2bff & 0xFF},
 	{0x2c00 & 0xFF, 0x2c5f & 0xFF},
 	{0x2c60 & 0xFF, 0x2c7f & 0xFF},
 	{0x2c80 & 0xFF, 0x2cf3 & 0xFF},
@@ -575,11 +574,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xa700 & 0xFF, 0xa721 & 0xFF},
 	{0xa722 & 0xFF, 0xa787 & 0xFF},
 	{0xa788 & 0xFF, 0xa78a & 0xFF},
-	{0xa78b & 0xFF, 0xa7cd & 0xFF},
-	{0xa7d0 & 0xFF, 0xa7d1 & 0xFF},
-	{0xa7d3 & 0xFF, 0xa7d3 & 0xFF},
-	{0xa7d5 & 0xFF, 0xa7dc & 0xFF},
-	{0xa7f2 & 0xFF, 0xa7ff & 0xFF},
+	{0xa78b & 0xFF, 0xa7dc & 0xFF},
+	{0xa7f1 & 0xFF, 0xa7ff & 0xFF},
 	{0xa800 & 0xFF, 0xa82c & 0xFF},
 	{0xa830 & 0xFF, 0xa839 & 0xFF},
 	{0xa840 & 0xFF, 0xa877 & 0xFF},
@@ -676,14 +672,11 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xfb40 & 0xFF, 0xfb41 & 0xFF},
 	{0xfb43 & 0xFF, 0xfb44 & 0xFF},
 	{0xfb46 & 0xFF, 0xfb4f & 0xFF},
-	{0xfb50 & 0xFF, 0xfbc2 & 0xFF},
-	{0xfbd3 & 0xFF, 0xfbff & 0xFF},
+	{0xfb50 & 0xFF, 0xfbff & 0xFF},
 	{0xfc00 & 0xFF, 0xfcff & 0xFF},
 	{0xfd00 & 0xFF, 0xfd3d & 0xFF},
 	{0xfd3e & 0xFF, 0xfd3f & 0xFF},
-	{0xfd40 & 0xFF, 0xfd8f & 0xFF},
-	{0xfd92 & 0xFF, 0xfdc7 & 0xFF},
-	{0xfdcf & 0xFF, 0xfdcf & 0xFF},
+	{0xfd40 & 0xFF, 0xfdcf & 0xFF},
 	{0xfdf0 & 0xFF, 0xfdff & 0xFF},
 	{0xfe00 & 0xFF, 0xfe0f & 0xFF},
 	{0xfe10 & 0xFF, 0xfe19 & 0xFF},
@@ -782,6 +775,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1091f & 0xFF, 0x1091f & 0xFF},
 	{0x10920 & 0xFF, 0x10939 & 0xFF},
 	{0x1093f & 0xFF, 0x1093f & 0xFF},
+	{0x10940 & 0xFF, 0x10959 & 0xFF},
 	{0x10980 & 0xFF, 0x1099f & 0xFF},
 	{0x109a0 & 0xFF, 0x109b7 & 0xFF},
 	{0x109bc & 0xFF, 0x109cf & 0xFF},
@@ -820,8 +814,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x10e80 & 0xFF, 0x10ea9 & 0xFF},
 	{0x10eab & 0xFF, 0x10ead & 0xFF},
 	{0x10eb0 & 0xFF, 0x10eb1 & 0xFF},
-	{0x10ec2 & 0xFF, 0x10ec4 & 0xFF},
-	{0x10efc & 0xFF, 0x10eff & 0xFF},
+	{0x10ec2 & 0xFF, 0x10ec7 & 0xFF},
+	{0x10ed0 & 0xFF, 0x10ed8 & 0xFF},
+	{0x10efa & 0xFF, 0x10eff & 0xFF},
 	{0x10f00 & 0xFF, 0x10f27 & 0xFF},
 	{0x10f30 & 0xFF, 0x10f59 & 0xFF},
 	{0x10f70 & 0xFF, 0x10f89 & 0xFF},
@@ -909,6 +904,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11ab0 & 0xFF, 0x11abf & 0xFF},
 	{0x11ac0 & 0xFF, 0x11af8 & 0xFF},
 	{0x11b00 & 0xFF, 0x11b09 & 0xFF},
+	{0x11b60 & 0xFF, 0x11b67 & 0xFF},
 	{0x11bc0 & 0xFF, 0x11be1 & 0xFF},
 	{0x11bf0 & 0xFF, 0x11bf9 & 0xFF},
 	{0x11c00 & 0xFF, 0x11c08 & 0xFF},
@@ -931,6 +927,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11d90 & 0xFF, 0x11d91 & 0xFF},
 	{0x11d93 & 0xFF, 0x11d98 & 0xFF},
 	{0x11da0 & 0xFF, 0x11da9 & 0xFF},
+	{0x11db0 & 0xFF, 0x11ddb & 0xFF},
+	{0x11de0 & 0xFF, 0x11de9 & 0xFF},
 	{0x11ee0 & 0xFF, 0x11ef8 & 0xFF},
 	{0x11f00 & 0xFF, 0x11f10 & 0xFF},
 	{0x11f12 & 0xFF, 0x11f3a & 0xFF},
@@ -989,6 +987,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x16b7d & 0xFF, 0x16b8f & 0xFF},
 	{0x16d40 & 0xFF, 0x16d79 & 0xFF},
 	{0x16e40 & 0xFF, 0x16e9a & 0xFF},
+	{0x16ea0 & 0xFF, 0x16eb8 & 0xFF},
+	{0x16ebb & 0xFF, 0x16ed3 & 0xFF},
 	{0x16f00 & 0xFF, 0x16f4a & 0xFF},
 	{0x16f4f & 0xFF, 0x16f87 & 0xFF},
 	{0x16f8f & 0xFF, 0x16f9f & 0xFF},
@@ -996,7 +996,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x16fe1 & 0xFF, 0x16fe1 & 0xFF},
 	{0x16fe2 & 0xFF, 0x16fe3 & 0xFF},
 	{0x16fe4 & 0xFF, 0x16fe4 & 0xFF},
-	{0x16ff0 & 0xFF, 0x16ff1 & 0xFF},
+	{0x16ff0 & 0xFF, 0x16ff6 & 0xFF},
 	{0x17000 & 0xFF, 0x170ff & 0xFF},
 	{0x17100 & 0xFF, 0x171ff & 0xFF},
 	{0x17200 & 0xFF, 0x172ff & 0xFF},
@@ -1020,14 +1020,15 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x18400 & 0xFF, 0x184ff & 0xFF},
 	{0x18500 & 0xFF, 0x185ff & 0xFF},
 	{0x18600 & 0xFF, 0x186ff & 0xFF},
-	{0x18700 & 0xFF, 0x187f7 & 0xFF},
+	{0x18700 & 0xFF, 0x187ff & 0xFF},
 	{0x18800 & 0xFF, 0x188ff & 0xFF},
 	{0x18900 & 0xFF, 0x189ff & 0xFF},
 	{0x18a00 & 0xFF, 0x18aff & 0xFF},
 	{0x18b00 & 0xFF, 0x18bff & 0xFF},
 	{0x18c00 & 0xFF, 0x18cd5 & 0xFF},
 	{0x18cff & 0xFF, 0x18cff & 0xFF},
-	{0x18d00 & 0xFF, 0x18d08 & 0xFF},
+	{0x18d00 & 0xFF, 0x18d1e & 0xFF},
+	{0x18d80 & 0xFF, 0x18df2 & 0xFF},
 	{0x1aff0 & 0xFF, 0x1aff3 & 0xFF},
 	{0x1aff5 & 0xFF, 0x1affb & 0xFF},
 	{0x1affd & 0xFF, 0x1affe & 0xFF},
@@ -1047,9 +1048,11 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1bc90 & 0xFF, 0x1bc99 & 0xFF},
 	{0x1bc9c & 0xFF, 0x1bc9f & 0xFF},
 	{0x1bca0 & 0xFF, 0x1bca3 & 0xFF},
-	{0x1cc00 & 0xFF, 0x1ccf9 & 0xFF},
+	{0x1cc00 & 0xFF, 0x1ccfc & 0xFF},
 	{0x1cd00 & 0xFF, 0x1cdff & 0xFF},
 	{0x1ce00 & 0xFF, 0x1ceb3 & 0xFF},
+	{0x1ceba & 0xFF, 0x1ced0 & 0xFF},
+	{0x1cee0 & 0xFF, 0x1cef0 & 0xFF},
 	{0x1cf00 & 0xFF, 0x1cf2d & 0xFF},
 	{0x1cf30 & 0xFF, 0x1cf46 & 0xFF},
 	{0x1cf50 & 0xFF, 0x1cfc3 & 0xFF},
@@ -1117,6 +1120,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1e4d0 & 0xFF, 0x1e4f9 & 0xFF},
 	{0x1e5d0 & 0xFF, 0x1e5fa & 0xFF},
 	{0x1e5ff & 0xFF, 0x1e5ff & 0xFF},
+	{0x1e6c0 & 0xFF, 0x1e6de & 0xFF},
+	{0x1e6e0 & 0xFF, 0x1e6f5 & 0xFF},
+	{0x1e6fe & 0xFF, 0x1e6ff & 0xFF},
 	{0x1e7e0 & 0xFF, 0x1e7e6 & 0xFF},
 	{0x1e7e8 & 0xFF, 0x1e7eb & 0xFF},
 	{0x1e7ed & 0xFF, 0x1e7ee & 0xFF},
@@ -1179,11 +1185,10 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1f300 & 0xFF, 0x1f3ff & 0xFF},
 	{0x1f400 & 0xFF, 0x1f4ff & 0xFF},
 	{0x1f500 & 0xFF, 0x1f5ff & 0xFF},
-	{0x1f600 & 0xFF, 0x1f6d7 & 0xFF},
+	{0x1f600 & 0xFF, 0x1f6d8 & 0xFF},
 	{0x1f6dc & 0xFF, 0x1f6ec & 0xFF},
 	{0x1f6f0 & 0xFF, 0x1f6fc & 0xFF},
-	{0x1f700 & 0xFF, 0x1f776 & 0xFF},
-	{0x1f77b & 0xFF, 0x1f7d9 & 0xFF},
+	{0x1f700 & 0xFF, 0x1f7d9 & 0xFF},
 	{0x1f7e0 & 0xFF, 0x1f7eb & 0xFF},
 	{0x1f7f0 & 0xFF, 0x1f7f0 & 0xFF},
 	{0x1f800 & 0xFF, 0x1f80b & 0xFF},
@@ -1193,17 +1198,19 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1f890 & 0xFF, 0x1f8ad & 0xFF},
 	{0x1f8b0 & 0xFF, 0x1f8bb & 0xFF},
 	{0x1f8c0 & 0xFF, 0x1f8c1 & 0xFF},
+	{0x1f8d0 & 0xFF, 0x1f8d8 & 0xFF},
 	{0x1f900 & 0xFF, 0x1f9ff & 0xFF},
-	{0x1fa00 & 0xFF, 0x1fa53 & 0xFF},
+	{0x1fa00 & 0xFF, 0x1fa57 & 0xFF},
 	{0x1fa60 & 0xFF, 0x1fa6d & 0xFF},
 	{0x1fa70 & 0xFF, 0x1fa7c & 0xFF},
-	{0x1fa80 & 0xFF, 0x1fa89 & 0xFF},
-	{0x1fa8f & 0xFF, 0x1fac6 & 0xFF},
-	{0x1face & 0xFF, 0x1fadc & 0xFF},
-	{0x1fadf & 0xFF, 0x1fae9 & 0xFF},
-	{0x1faf0 & 0xFF, 0x1faf8 & 0xFF},
+	{0x1fa80 & 0xFF, 0x1fa8a & 0xFF},
+	{0x1fa8e & 0xFF, 0x1fac6 & 0xFF},
+	{0x1fac8 & 0xFF, 0x1fac8 & 0xFF},
+	{0x1facd & 0xFF, 0x1fadc & 0xFF},
+	{0x1fadf & 0xFF, 0x1faea & 0xFF},
+	{0x1faef & 0xFF, 0x1faf8 & 0xFF},
 	{0x1fb00 & 0xFF, 0x1fb92 & 0xFF},
-	{0x1fb94 & 0xFF, 0x1fbf9 & 0xFF},
+	{0x1fb94 & 0xFF, 0x1fbfa & 0xFF},
 	{0x20000 & 0xFF, 0x200ff & 0xFF},
 	{0x20100 & 0xFF, 0x201ff & 0xFF},
 	{0x20200 & 0xFF, 0x202ff & 0xFF},
@@ -1387,8 +1394,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x2b400 & 0xFF, 0x2b4ff & 0xFF},
 	{0x2b500 & 0xFF, 0x2b5ff & 0xFF},
 	{0x2b600 & 0xFF, 0x2b6ff & 0xFF},
-	{0x2b700 & 0xFF, 0x2b739 & 0xFF},
-	{0x2b740 & 0xFF, 0x2b7ff & 0xFF},
+	{0x2b700 & 0xFF, 0x2b7ff & 0xFF},
 	{0x2b800 & 0xFF, 0x2b81d & 0xFF},
 	{0x2b820 & 0xFF, 0x2b8ff & 0xFF},
 	{0x2b900 & 0xFF, 0x2b9ff & 0xFF},
@@ -1412,7 +1418,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x2cb00 & 0xFF, 0x2cbff & 0xFF},
 	{0x2cc00 & 0xFF, 0x2ccff & 0xFF},
 	{0x2cd00 & 0xFF, 0x2cdff & 0xFF},
-	{0x2ce00 & 0xFF, 0x2cea1 & 0xFF},
+	{0x2ce00 & 0xFF, 0x2cead & 0xFF},
 	{0x2ceb0 & 0xFF, 0x2ceff & 0xFF},
 	{0x2cf00 & 0xFF, 0x2cfff & 0xFF},
 	{0x2d000 & 0xFF, 0x2d0ff & 0xFF},
@@ -1486,7 +1492,24 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x32000 & 0xFF, 0x320ff & 0xFF},
 	{0x32100 & 0xFF, 0x321ff & 0xFF},
 	{0x32200 & 0xFF, 0x322ff & 0xFF},
-	{0x32300 & 0xFF, 0x323af & 0xFF},
+	{0x32300 & 0xFF, 0x323ff & 0xFF},
+	{0x32400 & 0xFF, 0x324ff & 0xFF},
+	{0x32500 & 0xFF, 0x325ff & 0xFF},
+	{0x32600 & 0xFF, 0x326ff & 0xFF},
+	{0x32700 & 0xFF, 0x327ff & 0xFF},
+	{0x32800 & 0xFF, 0x328ff & 0xFF},
+	{0x32900 & 0xFF, 0x329ff & 0xFF},
+	{0x32a00 & 0xFF, 0x32aff & 0xFF},
+	{0x32b00 & 0xFF, 0x32bff & 0xFF},
+	{0x32c00 & 0xFF, 0x32cff & 0xFF},
+	{0x32d00 & 0xFF, 0x32dff & 0xFF},
+	{0x32e00 & 0xFF, 0x32eff & 0xFF},
+	{0x32f00 & 0xFF, 0x32fff & 0xFF},
+	{0x33000 & 0xFF, 0x330ff & 0xFF},
+	{0x33100 & 0xFF, 0x331ff & 0xFF},
+	{0x33200 & 0xFF, 0x332ff & 0xFF},
+	{0x33300 & 0xFF, 0x333ff & 0xFF},
+	{0x33400 & 0xFF, 0x33479 & 0xFF},
 	{0xe0001 & 0xFF, 0xe0001 & 0xFF},
 	{0xe0020 & 0xFF, 0xe007f & 0xFF},
 	{0xe0100 & 0xFF, 0xe01ef & 0xFF}};
@@ -1571,7 +1594,6 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_syriac,
 	unicode_script_arabic,
 	unicode_script_arabic,
-	unicode_script_arabic,
 	unicode_script_common,
 	unicode_script_arabic,
 	unicode_script_devanagari,
@@ -1795,6 +1817,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_tai_tham,
 	unicode_script_tai_tham,
 	unicode_script_inherited,
+	unicode_script_inherited,
 	unicode_script_balinese,
 	unicode_script_balinese,
 	unicode_script_sundanese,
@@ -1885,7 +1908,6 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_common,
 	unicode_script_common,
 	unicode_script_common,
-	unicode_script_common,
 	unicode_script_glagolitic,
 	unicode_script_latin,
 	unicode_script_coptic,
@@ -2070,9 +2092,6 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_common,
 	unicode_script_latin,
 	unicode_script_latin,
-	unicode_script_latin,
-	unicode_script_latin,
-	unicode_script_latin,
 	unicode_script_syloti_nagri,
 	unicode_script_common,
 	unicode_script_phags_pa,
@@ -2172,12 +2191,9 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_arabic,
 	unicode_script_arabic,
 	unicode_script_arabic,
-	unicode_script_arabic,
 	unicode_script_common,
 	unicode_script_arabic,
 	unicode_script_arabic,
-	unicode_script_arabic,
-	unicode_script_arabic,
 	unicode_script_inherited,
 	unicode_script_common,
 	unicode_script_inherited,
@@ -2275,6 +2291,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_phoenician,
 	unicode_script_lydian,
 	unicode_script_lydian,
+	unicode_script_sidetic,
 	unicode_script_meroitic_hieroglyphs,
 	unicode_script_meroitic_cursive,
 	unicode_script_meroitic_cursive,
@@ -2315,6 +2332,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_yezidi,
 	unicode_script_arabic,
 	unicode_script_arabic,
+	unicode_script_arabic,
 	unicode_script_old_sogdian,
 	unicode_script_sogdian,
 	unicode_script_old_uyghur,
@@ -2402,6 +2420,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_canadian_aboriginal,
 	unicode_script_pau_cin_hau,
 	unicode_script_devanagari,
+	unicode_script_sharada,
 	unicode_script_sunuwar,
 	unicode_script_sunuwar,
 	unicode_script_bhaiksuki,
@@ -2424,6 +2443,8 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_gunjala_gondi,
 	unicode_script_gunjala_gondi,
 	unicode_script_gunjala_gondi,
+	unicode_script_tolong_siki,
+	unicode_script_tolong_siki,
 	unicode_script_makasar,
 	unicode_script_kawi,
 	unicode_script_kawi,
@@ -2482,6 +2503,8 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_pahawh_hmong,
 	unicode_script_kirat_rai,
 	unicode_script_medefaidrin,
+	unicode_script_beria_erfe,
+	unicode_script_beria_erfe,
 	unicode_script_miao,
 	unicode_script_miao,
 	unicode_script_miao,
@@ -2521,6 +2544,7 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_khitan_small_script,
 	unicode_script_khitan_small_script,
 	unicode_script_tangut,
+	unicode_script_tangut,
 	unicode_script_katakana,
 	unicode_script_katakana,
 	unicode_script_katakana,
@@ -2543,6 +2567,8 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_common,
 	unicode_script_common,
 	unicode_script_common,
+	unicode_script_common,
+	unicode_script_common,
 	unicode_script_inherited,
 	unicode_script_inherited,
 	unicode_script_common,
@@ -2610,6 +2636,9 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_nag_mundari,
 	unicode_script_ol_onal,
 	unicode_script_ol_onal,
+	unicode_script_tai_yo,
+	unicode_script_tai_yo,
+	unicode_script_tai_yo,
 	unicode_script_ethiopic,
 	unicode_script_ethiopic,
 	unicode_script_ethiopic,
@@ -2697,6 +2726,23 @@ static const uint8_t unicode_classtab[]={
 	unicode_script_common,
 	unicode_script_common,
 	unicode_script_common,
+	unicode_script_common,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
+	unicode_script_han,
 	unicode_script_han,
 	unicode_script_han,
 	unicode_script_han,
@@ -3334,6 +3380,7 @@ static const size_t unicode_starting_indextab[]={
 	482,
 	484,
 	485,
+	486,
 	487,
 	488,
 	489,
@@ -3630,6 +3677,23 @@ static const size_t unicode_starting_indextab[]={
 	801,
 	802,
 	803,
+	804,
+	805,
+	806,
+	807,
+	808,
+	809,
+	810,
+	811,
+	812,
+	813,
+	814,
+	815,
+	816,
+	817,
+	818,
+	819,
+	820,
 	3584,
 	3585
 };
@@ -3644,24 +3708,24 @@ static const char32_t unicode_starting_pagetab[]={
 	48,
 	65,
 	72,
-	82,
-	101,
-	131,
-	161,
-	187,
-	206,
-	220,
-	228,
+	81,
+	100,
+	130,
+	160,
+	186,
+	205,
+	219,
+	227,
+	234,
 	235,
-	236,
-	250,
+	249,
+	256,
 	257,
 	258,
-	259,
-	264,
-	275,
-	283,
-	295,
+	263,
+	274,
+	282,
+	294,
 	303,
 	308,
 	328,
@@ -3679,14 +3743,15 @@ static const char32_t unicode_starting_pagetab[]={
 	389,
 	390,
 	391,
-	394,
-	398,
-	414,
-	417,
-	419,
-	438,
-	445,
-	451,
+	393,
+	397,
+	413,
+	416,
+	418,
+	437,
+	444,
+	450,
+	452,
 	453,
 	454,
 	455,
@@ -3712,7 +3777,7 @@ static const char32_t unicode_starting_pagetab[]={
 	475,
 	476,
 	477,
-	478,
+	479,
 	480,
 	481,
 	482,
@@ -3799,14 +3864,17 @@ static const char32_t unicode_starting_pagetab[]={
 	563,
 	564,
 	565,
-	566,
+	568,
 	569,
-	570,
-	573,
-	581,
-	587,
-	598,
-	606,
+	572,
+	577,
+	583,
+	594,
+	602,
+	616,
+	617,
+	618,
+	619,
 	620,
 	621,
 	622,
@@ -3847,61 +3915,59 @@ static const char32_t unicode_starting_pagetab[]={
 	657,
 	658,
 	659,
-	660,
-	661,
 	662,
 	663,
-	666,
-	667,
-	669,
+	665,
+	674,
+	675,
 	679,
-	680,
-	686,
-	696,
+	689,
+	706,
 	713,
-	720,
-	728,
-	732,
-	740,
-	746,
+	721,
+	725,
+	733,
+	739,
+	751,
+	752,
 	758,
-	759,
-	765,
-	779,
-	787,
-	799,
-	808,
-	812,
-	817,
+	772,
+	781,
+	793,
+	802,
+	806,
+	811,
+	818,
 	823,
-	828,
+	830,
 	835,
-	840,
-	849,
-	876,
-	880,
-	882,
-	888,
-	891,
-	894,
-	905,
-	909,
-	912,
-	919,
-	932,
-	933,
+	844,
+	871,
+	875,
+	877,
+	883,
+	886,
+	889,
+	900,
+	904,
+	908,
+	915,
+	930,
+	931,
+	937,
+	938,
 	939,
 	940,
 	941,
-	942,
-	943,
+	944,
+	945,
 	946,
 	947,
 	948,
 	949,
 	950,
-	951,
 	952,
+	953,
 	954,
 	955,
 	956,
@@ -3922,11 +3988,9 @@ static const char32_t unicode_starting_pagetab[]={
 	971,
 	972,
 	973,
-	974,
-	975,
-	983,
-	988,
-	989,
+	981,
+	986,
+	987,
 	990,
 	998,
 	999,
@@ -3958,57 +4022,51 @@ static const char32_t unicode_starting_pagetab[]={
 	1025,
 	1026,
 	1028,
-	1029,
-	1032,
-	1034,
-	1041,
+	1030,
+	1033,
+	1035,
 	1042,
-	1048,
+	1043,
 	1049,
 	1050,
 	1051,
 	1054,
-	1055,
-	1065,
+	1057,
+	1058,
 	1068,
-	1070,
-	1080,
-	1090,
-	1092,
-	1094,
+	1071,
+	1073,
+	1083,
+	1093,
 	1095,
-	1096,
+	1097,
+	1098,
 	1099,
-	1101,
-	1108,
-	1112,
+	1102,
+	1104,
+	1111,
 	1115,
-	1116,
 	1118,
-	1122,
+	1119,
+	1121,
 	1124,
-	1127,
 	1128,
-	1129,
-	1163,
+	1130,
+	1133,
+	1134,
+	1135,
 	1169,
-	1171,
+	1175,
 	1177,
-	1178,
-	1179,
-	1180,
 	1183,
-	1187,
-	1194,
-	1195,
-	1203,
-	1205,
-	1206,
-	1207,
-	1208,
-	1209,
+	1184,
+	1185,
+	1186,
+	1189,
+	1192,
+	1200,
+	1201,
 	1210,
-	1211,
 	1212,
 	1213,
 	1214,
@@ -4186,13 +4244,14 @@ static const char32_t unicode_starting_pagetab[]={
 	1386,
 	1387,
 	1388,
+	1389,
 	1390,
+	1391,
 	1392,
 	1393,
 	1394,
 	1395,
 	1396,
-	1397,
 	1398,
 	1399,
 	1400,
@@ -4209,12 +4268,12 @@ static const char32_t unicode_starting_pagetab[]={
 	1411,
 	1412,
 	1413,
+	1414,
 	1415,
 	1416,
 	1417,
 	1418,
 	1419,
-	1420,
 	1421,
 	1422,
 	1423,
@@ -4238,12 +4297,12 @@ static const char32_t unicode_starting_pagetab[]={
 	1441,
 	1442,
 	1443,
+	1444,
 	1445,
 	1446,
 	1447,
 	1448,
 	1449,
-	1450,
 	1451,
 	1452,
 	1453,
@@ -4264,12 +4323,12 @@ static const char32_t unicode_starting_pagetab[]={
 	1468,
 	1469,
 	1470,
+	1471,
 	1472,
 	1473,
 	1474,
 	1475,
 	1476,
-	1477,
 	1478,
 	1479,
 	1480,
@@ -4281,6 +4340,29 @@ static const char32_t unicode_starting_pagetab[]={
 	1486,
 	1487,
 	1488,
-	1490
+	1489,
+	1490,
+	1491,
+	1492,
+	1493,
+	1494,
+	1495,
+	1496,
+	1497,
+	1498,
+	1499,
+	1500,
+	1501,
+	1502,
+	1503,
+	1504,
+	1505,
+	1506,
+	1507,
+	1508,
+	1509,
+	1510,
+	1511,
+	1513
 };
 
