@@ -18,6 +18,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x00ad & 0xFF, 0x00ad & 0xFF},
 	{0x00b5 & 0xFF, 0x00b5 & 0xFF},
 	{0x00b7 & 0xFF, 0x00b7 & 0xFF},
+	{0x00b8 & 0xFF, 0x00b8 & 0xFF},
 	{0x00ba & 0xFF, 0x00ba & 0xFF},
 	{0x00c0 & 0xFF, 0x00d6 & 0xFF},
 	{0x00d8 & 0xFF, 0x00f6 & 0xFF},
@@ -107,7 +108,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0859 & 0xFF, 0x085b & 0xFF},
 	{0x0860 & 0xFF, 0x086a & 0xFF},
 	{0x0870 & 0xFF, 0x0887 & 0xFF},
-	{0x0889 & 0xFF, 0x088e & 0xFF},
+	{0x0889 & 0xFF, 0x088f & 0xFF},
 	{0x0890 & 0xFF, 0x0891 & 0xFF},
 	{0x0897 & 0xFF, 0x089f & 0xFF},
 	{0x08a0 & 0xFF, 0x08c9 & 0xFF},
@@ -230,7 +231,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0c4a & 0xFF, 0x0c4d & 0xFF},
 	{0x0c55 & 0xFF, 0x0c56 & 0xFF},
 	{0x0c58 & 0xFF, 0x0c5a & 0xFF},
-	{0x0c5d & 0xFF, 0x0c5d & 0xFF},
+	{0x0c5c & 0xFF, 0x0c5d & 0xFF},
 	{0x0c60 & 0xFF, 0x0c61 & 0xFF},
 	{0x0c62 & 0xFF, 0x0c63 & 0xFF},
 	{0x0c66 & 0xFF, 0x0c6f & 0xFF},
@@ -247,7 +248,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0cc6 & 0xFF, 0x0cc8 & 0xFF},
 	{0x0cca & 0xFF, 0x0ccd & 0xFF},
 	{0x0cd5 & 0xFF, 0x0cd6 & 0xFF},
-	{0x0cdd & 0xFF, 0x0cde & 0xFF},
+	{0x0cdc & 0xFF, 0x0cde & 0xFF},
 	{0x0ce0 & 0xFF, 0x0ce1 & 0xFF},
 	{0x0ce2 & 0xFF, 0x0ce3 & 0xFF},
 	{0x0ce6 & 0xFF, 0x0cef & 0xFF},
@@ -385,7 +386,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1a7f & 0xFF, 0x1a7f & 0xFF},
 	{0x1a80 & 0xFF, 0x1a89 & 0xFF},
 	{0x1a90 & 0xFF, 0x1a99 & 0xFF},
-	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
+	{0x1ab0 & 0xFF, 0x1add & 0xFF},
+	{0x1ae0 & 0xFF, 0x1aeb & 0xFF},
 	{0x1b00 & 0xFF, 0x1b04 & 0xFF},
 	{0x1b05 & 0xFF, 0x1b33 & 0xFF},
 	{0x1b34 & 0xFF, 0x1b44 & 0xFF},
@@ -529,11 +531,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xa69e & 0xFF, 0xa69f & 0xFF},
 	{0xa6a0 & 0xFF, 0xa6ef & 0xFF},
 	{0xa6f0 & 0xFF, 0xa6f1 & 0xFF},
-	{0xa708 & 0xFF, 0xa7cd & 0xFF},
-	{0xa7d0 & 0xFF, 0xa7d1 & 0xFF},
-	{0xa7d3 & 0xFF, 0xa7d3 & 0xFF},
-	{0xa7d5 & 0xFF, 0xa7dc & 0xFF},
-	{0xa7f2 & 0xFF, 0xa7ff & 0xFF},
+	{0xa708 & 0xFF, 0xa7dc & 0xFF},
+	{0xa7f1 & 0xFF, 0xa7ff & 0xFF},
 	{0xa800 & 0xFF, 0xa801 & 0xFF},
 	{0xa802 & 0xFF, 0xa802 & 0xFF},
 	{0xa803 & 0xFF, 0xa805 & 0xFF},
@@ -740,6 +739,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x108f4 & 0xFF, 0x108f5 & 0xFF},
 	{0x10900 & 0xFF, 0x10915 & 0xFF},
 	{0x10920 & 0xFF, 0x10939 & 0xFF},
+	{0x10940 & 0xFF, 0x10959 & 0xFF},
 	{0x10980 & 0xFF, 0x109b7 & 0xFF},
 	{0x109be & 0xFF, 0x109bf & 0xFF},
 	{0x10a00 & 0xFF, 0x10a00 & 0xFF},
@@ -773,8 +773,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x10e80 & 0xFF, 0x10ea9 & 0xFF},
 	{0x10eab & 0xFF, 0x10eac & 0xFF},
 	{0x10eb0 & 0xFF, 0x10eb1 & 0xFF},
-	{0x10ec2 & 0xFF, 0x10ec4 & 0xFF},
-	{0x10efc & 0xFF, 0x10eff & 0xFF},
+	{0x10ec2 & 0xFF, 0x10ec7 & 0xFF},
+	{0x10efa & 0xFF, 0x10eff & 0xFF},
 	{0x10f00 & 0xFF, 0x10f1c & 0xFF},
 	{0x10f27 & 0xFF, 0x10f27 & 0xFF},
 	{0x10f30 & 0xFF, 0x10f45 & 0xFF},
@@ -929,6 +929,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11a8a & 0xFF, 0x11a99 & 0xFF},
 	{0x11a9d & 0xFF, 0x11a9d & 0xFF},
 	{0x11ab0 & 0xFF, 0x11af8 & 0xFF},
+	{0x11b60 & 0xFF, 0x11b67 & 0xFF},
 	{0x11bc0 & 0xFF, 0x11be0 & 0xFF},
 	{0x11bf0 & 0xFF, 0x11bf9 & 0xFF},
 	{0x11c00 & 0xFF, 0x11c08 & 0xFF},
@@ -958,6 +959,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11d93 & 0xFF, 0x11d97 & 0xFF},
 	{0x11d98 & 0xFF, 0x11d98 & 0xFF},
 	{0x11da0 & 0xFF, 0x11da9 & 0xFF},
+	{0x11db0 & 0xFF, 0x11ddb & 0xFF},
+	{0x11de0 & 0xFF, 0x11de9 & 0xFF},
 	{0x11ee0 & 0xFF, 0x11ef2 & 0xFF},
 	{0x11ef3 & 0xFF, 0x11ef6 & 0xFF},
 	{0x11f00 & 0xFF, 0x11f01 & 0xFF},
@@ -1027,6 +1030,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x16d40 & 0xFF, 0x16d6c & 0xFF},
 	{0x16d70 & 0xFF, 0x16d79 & 0xFF},
 	{0x16e40 & 0xFF, 0x16e7f & 0xFF},
+	{0x16ea0 & 0xFF, 0x16eb8 & 0xFF},
+	{0x16ebb & 0xFF, 0x16ed3 & 0xFF},
 	{0x16f00 & 0xFF, 0x16f4a & 0xFF},
 	{0x16f4f & 0xFF, 0x16f4f & 0xFF},
 	{0x16f50 & 0xFF, 0x16f50 & 0xFF},
@@ -1126,6 +1131,16 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1e5ee & 0xFF, 0x1e5ef & 0xFF},
 	{0x1e5f0 & 0xFF, 0x1e5f0 & 0xFF},
 	{0x1e5f1 & 0xFF, 0x1e5fa & 0xFF},
+	{0x1e6c0 & 0xFF, 0x1e6de & 0xFF},
+	{0x1e6e0 & 0xFF, 0x1e6e2 & 0xFF},
+	{0x1e6e3 & 0xFF, 0x1e6e3 & 0xFF},
+	{0x1e6e4 & 0xFF, 0x1e6e5 & 0xFF},
+	{0x1e6e6 & 0xFF, 0x1e6e6 & 0xFF},
+	{0x1e6e7 & 0xFF, 0x1e6ed & 0xFF},
+	{0x1e6ee & 0xFF, 0x1e6ef & 0xFF},
+	{0x1e6f0 & 0xFF, 0x1e6f4 & 0xFF},
+	{0x1e6f5 & 0xFF, 0x1e6f5 & 0xFF},
+	{0x1e6fe & 0xFF, 0x1e6ff & 0xFF},
 	{0x1e7e0 & 0xFF, 0x1e7e6 & 0xFF},
 	{0x1e7e8 & 0xFF, 0x1e7eb & 0xFF},
 	{0x1e7ed & 0xFF, 0x1e7ee & 0xFF},
@@ -1206,6 +1221,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -1568,6 +1584,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Numeric,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
+	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
@@ -1713,9 +1730,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
-	UNICODE_WB_ALetter,
-	UNICODE_WB_ALetter,
-	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
@@ -1924,6 +1938,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
@@ -2110,6 +2125,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
@@ -2140,6 +2156,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Numeric,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
@@ -2209,6 +2227,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
@@ -2309,6 +2329,16 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -2553,6 +2583,7 @@ static const size_t unicode_starting_indextab[]={
 	482,
 	484,
 	485,
+	486,
 	487,
 	488,
 	489,
@@ -2566,59 +2597,60 @@ static const size_t unicode_starting_indextab[]={
 
 static const char32_t unicode_starting_pagetab[]={
 	0,
-	23,
 	24,
-	26,
-	39,
-	42,
-	59,
-	82,
-	96,
-	115,
-	147,
-	184,
-	219,
-	254,
-	282,
-	290,
-	305,
-	321,
+	25,
+	27,
+	40,
+	43,
+	60,
+	83,
+	97,
+	116,
+	148,
+	185,
+	220,
+	255,
+	283,
+	291,
+	306,
 	322,
-	336,
-	343,
+	323,
+	337,
 	344,
 	345,
-	351,
-	363,
-	374,
-	379,
-	387,
-	400,
-	418,
+	346,
+	352,
+	364,
+	375,
+	380,
+	389,
+	402,
 	420,
-	421,
-	440,
-	461,
-	475,
-	476,
-	480,
-	496,
-	497,
-	506,
-	510,
-	511,
+	422,
+	423,
+	442,
+	463,
+	477,
+	478,
+	482,
+	498,
+	499,
+	508,
 	512,
 	513,
 	514,
 	515,
 	516,
+	517,
 	518,
-	519,
-	530,
-	535,
-	554,
-	567,
-	584,
+	520,
+	521,
+	532,
+	534,
+	553,
+	566,
+	583,
+	593,
 	594,
 	595,
 	596,
@@ -2662,22 +2694,21 @@ static const char32_t unicode_starting_pagetab[]={
 	634,
 	635,
 	636,
-	637,
-	640,
+	639,
+	652,
 	653,
-	654,
-	658,
-	670,
-	687,
-	694,
-	696,
-	699,
-	707,
-	711,
+	657,
+	669,
+	686,
+	693,
+	695,
+	698,
+	706,
+	710,
+	721,
 	722,
-	723,
-	729,
-	739,
+	728,
+	738,
 	743,
 	757,
 	761,
@@ -2696,25 +2727,22 @@ static const char32_t unicode_starting_pagetab[]={
 	897,
 	917,
 	930,
-	932,
-	941,
-	959,
-	961,
-	971,
-	972,
-	973,
+	933,
+	942,
+	962,
+	964,
 	974,
 	975,
+	976,
 	977,
 	978,
-	979,
 	980,
 	981,
 	982,
 	983,
-	989,
-	990,
-	991,
+	984,
+	985,
+	986,
 	992,
 	993,
 	994,
@@ -2731,40 +2759,44 @@ static const char32_t unicode_starting_pagetab[]={
 	1005,
 	1006,
 	1007,
+	1008,
+	1009,
 	1010,
-	1011,
-	1012,
-	1019,
-	1025,
-	1027,
+	1013,
+	1014,
+	1015,
+	1022,
 	1028,
-	1038,
-	1041,
-	1042,
-	1045,
-	1051,
-	1052,
-	1054,
-	1060,
-	1061,
-	1071,
-	1081,
+	1030,
+	1033,
+	1043,
+	1046,
+	1047,
+	1050,
+	1056,
+	1057,
+	1059,
+	1065,
+	1066,
+	1076,
 	1086,
-	1095,
-	1101,
-	1103,
-	1110,
+	1091,
+	1100,
+	1106,
+	1108,
 	1115,
 	1120,
-	1123,
-	1127,
-	1131,
-	1133,
-	1137,
-	1170,
-	1174,
-	1175,
-	1176,
-	1178
+	1125,
+	1128,
+	1132,
+	1142,
+	1146,
+	1148,
+	1152,
+	1185,
+	1189,
+	1190,
+	1191,
+	1193
 };
 
